@@ -8,7 +8,7 @@ import pickle
 import random
 import sys
 from functools import wraps
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, TypeVar
 
 import moderngl
 import numpy as np
@@ -64,8 +64,9 @@ if TYPE_CHECKING:
     import numpy.typing as npt
     from colour import Color
 
-    TimeBasedUpdater = Callable[["Mobject", float], None]
-    NonTimeUpdater = Callable[["Mobject"], None]
+    T = TypeVar("T", bound="Mobject")
+    TimeBasedUpdater = Callable[[T, float], None | T]
+    NonTimeUpdater = Callable[[T], None | T]
     Updater = Union[TimeBasedUpdater, NonTimeUpdater]
     ManimColor = Union[str, Color]
 
